#
# spec file for package libqt5-qtquickcontrols
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML imports of examples
%global __requires_exclude qmlimport\\(.*example.*

%define qt5_snapshot 1
%define base_name libqt5
%define real_version 5.15.13
%define so_version 5.15.13
%define tar_version qtquickcontrols-everywhere-src-%{version}
Name:           libqt5-qtquickcontrols
Version:        5.15.13+kde0
Release:        1.2
Summary:        Qt 5 Quick Controls Addon
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
# PATCH-FIX-OPENSUSE
Patch1:         fix-handle-deps.patch
BuildRequires:  fdupes
BuildRequires:  libQt5Core-private-headers-devel >= %{real_version}
BuildRequires:  libQt5Gui-private-headers-devel >= %{real_version}
BuildRequires:  libqt5-qtbase-devel >= %{real_version}
BuildRequires:  libqt5-qtdeclarative-private-headers-devel >= %{real_version}
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(Qt5Qml) >= %{real_version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{real_version}
%requires_ge    libQt5Widgets5
%requires_ge    libQtQuick5

%description
The Qt Quick Controls module provides a set of controls that
can be used to build complete interfaces in Qt Quick.

%package examples
Summary:        Qt5 quickcontrols examples
License:        BSD-3-Clause
Group:          Development/Libraries/X11

%description examples
Examples for libqt5-qtquickcontrols module.

%prep
%autosetup -p1 -n %{tar_version}

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5
%make_jobs

%install
%qmake5_install

%files
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_archdatadir}/qml/QtQuick

%files examples
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Tue Mar 19 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.13+kde0, rebased upstream:
  * QQuickAbstractDialog: treat closing as rejection
  * Bump version to 5.15.13
* Fri Dec 29 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde0, rebased upstream:
  * Bump version to 5.15.12
  * Remove tests for StackLayout
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde0, rebased upstream:
  * Blacklist Tests_StackLayout::test_addAndRemoveItems
  * Blacklist Windows on Tests_StackLayout::test_addAndRemoveItems
  * Blacklist 1 tests in qtquickcontrols on macos
  * Blacklist 1 tests in qtquickcontrols on ubuntu-20.04
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde0, rebased upstream:
  * No code changes
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde2, rebased upstream:
  * No code changes
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde0, rebased upstream:
  * No code changes
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde0, rebased upstream:
  * No code changes
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde0, rebased upstream:
  * No code changes
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde0, rebased upstream:
  * Fix warning with QML FileDialog with many files
  * Revert "Update commercial license headers"
  * Update commercial license headers
  * ColorDialog: Set the options before the current color on the helper
  * [Android] Fix CheckBox rtl issues
  * [Android] Fix FontDialog layout issues
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Tue Jun 22 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde3:
  * Convert the path to a url correctly
  * Add changes file for Qt 5.15.2
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
* Sat Jan 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Mon Dec 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix unfullfillable import:
  * fix-handle-deps.patch
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Tue Dec 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tags.
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtquickcontrols.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtquickcontrols.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.13.0/?h=5.13
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.13.0/?h=5.13
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.12.2/?h=5.12.2
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.12.0/?h=5.12.0
- Remove patches, now upstream:
  * fix-menu-buttons-not-opening.patch
* Thu Nov 22 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix menus not opening more than once (QTBUG-71238, kde#399914):
  * fix-menu-buttons-not-opening.patch
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtquickcontrols.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
- Add minimal requires on libQt5Widgets5 and libQtQuick5
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
- Drop 0001-Correct-sizing-of-combobox-items.patch, merged upstream
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Added 0001-Correct-sizing-of-combobox-items.patch from upstream
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2 final
  * No changes since previous snapshot
  * Use official tars
* Thu Sep  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2~git20140904 (ra7d03f5):
  * Tip of the bugfix 5.3.2 branch:
  * Fix menu/combobox popup positioning
  * Dialogs: correct C++ warnings
  * Dialogs must know when they are closed by the
    operating system
  * Dialog: initialize enabled and clicked buttons
  * Dialogs: buttonless fully-filled dialog example
  * Dialog: do not emit signals twice when a button
    is clicked
  * QtQuick.Dialogs FileDialog: default mode is ExistingFile
  * QtQuick.Dialogs FontDialog: fix a binding loop issue
  * Fix tooltip position when used with QQuickWidget
  * Doc: Updated the Calendar example documentation
  * Make the default style "Base" when built without
    widgets support
  * QQuickPopupWindow: Use actual item size as content size
  * QtQuick.Dialogs: check for inheriting from QApplication
  * Updated the example so that it adapts to the
    orientation change
  * Centralize determination of "no desktop" configurations
  * Do not embed the Desktop style into resources on
    irrelevant platforms
  * Improve implicit size of Calendar on high DPI devices.
  * MenuStyle: fix default text rendering type
  * SpinBox: don't force active focus when tapping
    the buttons on touch
  * Fixed incorrect cursor when moving column in TableView
  * Doc: Updated the example documentation
  * Dialog: Add missing docs
  * Fix editable ComboBox mouse cursor
  * Doc: Update image for ApplicationWindow
  * Fix SpinBox mouse cursor
  * Mention that ApplicationWindow is not visible by default.
  * Allow QT_QUICK_CONTROLS_STYLE pointing to resources
  * TextField/Area: soft dependency to inputMethodHints
  * Use the correct parent window for menu popups
  * Revise unstable and slow GridLayout auto test
  * Doc: Add a link to Tab in TabView documentation
  * Doc: Added images and missing snippets
  * Cleanup whitespace
  * Remove QtWidgets dependency for WinRT
  * Remove Widgets dependency for QNX
  * ComboBox: open the popup on release on touch devices
  * Slider: fix behavior inside a flickable on touch
  * Singleton SystemPalette
  * Kill unnecessary SystemPalette instances
  * Remove unused BasicButton::__textColor
  * Fix grammar in Layout::fillWidth and
    Layout::fillHeight documentation.
* Thu Aug  7 2014 hrvoje.senjan@gmail.com
- Fix summary and description
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
* Mon May 19 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 final
  * Minor bugfixes over previous RC
* Thu May  8 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 RC
  * For more details, please see
  http://blog.qt.digia.com/blog/2014/05/08/qt-5-3-release-candidate-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/03/25/qt-5-3-beta-released/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
- Added libqt5-qtbase-devel BuildRequires, to build examples subpackage
* Mon Feb 10 2014 mlin@suse.com
- Install LICENSE files to %%doc
* Wed Feb  5 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/02/05/qt-5-2-1-released/
* Thu Dec 12 2013 hrvoje.senjan@gmail.com
- Update to 5.2.0 final:
  * For more details please see:
    http://blog.qt.digia.com/blog/2013/12/12/qt-5-2-released-the-best-qt-yet/
    http://qt-project.org/qt5/qt52
    http://qt.digia.com/Product/Whats-New/Qt-52/
* Fri Nov 29 2013 hrvoje.senjan@gmail.com
- Update to 5.2 rc1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/11/29/qt-5-2-release-candidate-1-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Wed Oct 23 2013 hrvoje.senjan@gmail.com
- Update to 5.2 beta1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/10/23/qt-5-2-beta-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Thu Aug 29 2013 hrvoje.senjan@gmail.com
- Update to version 5.1.1:
  * Bugfix release, please see
  http://blog.qt.digia.com/blog/2013/08/28/qt-5-1-1-released/
  http://qt.gitorious.org/qt/qtquickcontrols/blobs/release/dist/changes-5.1.1
  and http://qt-project.org/wiki/Qt511KnownIssues for known issues
- Small spec cleanup
* Sun Jul  7 2013 stephan.binner@basyskom.com
- update to Qt 5.1 release
* Tue Jun 18 2013 stephan.binner@basyskom.com
- update to Qt 5.1 RC 1
* Mon May 20 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Beta 1
* Tue Apr  9 2013 stephan.binner@basyskom.com
- initial package for Qt 5.1 Alpha 1
